<div class="container-fluid" id="featured-bills">
    <div class="row-fluid">
        <div class='col-sm-10 col-sm-offset-1'>

            <div class="well well-featured">

                <h3>
                   <span class="small">
                        <i class="fa fa-star"></i>
                        FEATURED LEGISLATION
                    </span><br/>
                    Study on Traffic Congestion &amp; For-Hire Vehicles
                </h3>
                <div class='row'>
                    <div class='col-sm-8'>
                        <p>
                            Mayor de Blasio has claimed that ride share services cause traffic problems. In August, he approved a bill to conduct a study on how growth in the for-hire industry has impacted traffic, air quality, noise, &amp; public health.
                        </p>
                        <p>
                            Uber <a href="http://www.capitalnewyork.com/article/city-hall/2015/09/8577153/uber-fight-city-hall-overshadows-congestion-hearing" target="_blank">accused the city of moving too fast</a>, asserting that a study should take longer than the four months provided and <a href="http://www.wsj.com/articles/uber-vs-city-hall-round-two-1442451813" target="_blank">commissioning its own study on the issue</a>.
                        </p>
                        <a href="/legislation/int-847-2015/" class="btn btn-sm btn-primary">
                            Details
                            <i class="fa fa-fw fa-chevron-right"></i>
                        </a>
                    </div>
                    <div class='col-sm-4 hidden-sm hidden-xs'>
                        <img class='img-responsive img-thumbnail' src='/static/images/featured/uber.png' />
                    </div>
                </div>
            </div>


            <div class="well well-featured">

                <h3>
                    <span class="small">
                        <i class="fa fa-star"></i>
                        FEATURED LEGISLATION
                    </span><br/>
                    Task Force on Police Body Cameras
                </h3>
                <div class='row'>
                    <div class='col-sm-8'>
                        <p>
                            After the deaths of Walter Scott in South Carolina and Eric Garner in New York, <a href="http://www.nydailynews.com/new-york/city-council-members-put-body-cameras-article-1.2180212" target="_blank">many called for police officers to wear body cameras</a> for accountability. This bill proposes the creation of a task force to study issues related to police body cameras.
                        </p>
                        <p>
                            This was one of nine police reform bills considered during a hearing on 6/29, held by the Committee on Public Safety. At the hearing, all nine bills were laid over, meaning that no further actions or votes were taken.
                        </p>
                        <a href="/legislation/int-607-2014/" class="btn btn-sm btn-primary">
                            Details
                            <i class="fa fa-fw fa-chevron-right"></i>
                        </a>
                    </div>
                    <div class='col-sm-4 hidden-sm hidden-xs'>
                        <img class='img-responsive img-thumbnail' src='/static/images/featured/body-cams.png' />
                    </div>
                </div>

            </div>





        </div>
    </div>
</div>