{% extends "base_with_margins.html" %}
{% block title %}About{% endblock %}
{% block content %}

    <div class="row-fluid clearfix">
        <div class="col-sm-8 no-pad-mobile">
            <br />
            <h1 id='about'>About</h1>
            
            <p><strong>NYC Councilmatic</strong> is a tool for understanding and tracking what’s happening in New York City Council.</p>
            <p>This site connects NYC residents to local city council offices, for greater online public dialogue about issues in their communities.</p>

            <p>Councilmatic helps you:</p>
            <ul>
                <li>
                    Keep up with what your local representatives is up to
                </li>
                <li>
                    See the schedule of public events
                </li>
                <li>
                    Track and comment on issues you care about
                </li>
            </ul>

            <p>NYC Councilmatic is <strong>free</strong>, <strong>non-profit</strong>, and <strong>non-partisan</strong> and the easiest way to access official New York City Council information.</p>

        </div>
        <div class="col-sm-4 desktop-only">
            <br/>
            <br>
            <div class="well well-sm">
                <h4>Contents</h4>
                <ul class="less-pad-list">
                    <li>
                        <a href="/about">About</a>
                    </li>
                    <li>
                        <a href="#about-city-council">What is New York City Council,<br />and how does it work?</a>
                    </li>
                    <li>
                        <a href="#open-source">We're open source!</a>
                    </li>
                    <li>
                        <a href="#data">Data</a>
                    </li>
                    <li>
                        <a href="#team">Team</a>
                    </li>
                    <li>
                        <a href="#contact">Contact us</a>
                    </li>
                    <li>
                        <a href="#bring-councilmatic">Bring Councilmatic to your city!</a>
                    </li>
                    <li>
                        <a href="#credits">Credits</a>
                    </li>
                </ul>
            </div>
        </div>
    </div>
    <div class="row-fluid">
        <div class="col-sm-8 no-pad-mobile" id="about-city-council">
            <br/><br/>
            <h3>What is New York City Council, and how does it work?</h3>

            <p><a href='https://en.wikipedia.org/wiki/New_York_City_Council'>New York City Council</a> is the lawmaking body of New York City.</p>

            <p>The Council is made up of <a href='/council-members/'>51 council seats</a>, with each representative typically serving a four year term.</p>

            <p>The Council is an equal partner with the <a href='https://en.wikipedia.org/wiki/Mayor_of_New_York_City'>Mayor</a> in governing New York City. Its responsibilities include:</p>
            <ul>
                <li>
                    Discussing and approving local legislation
                </li>
                <li>
                    Making <a href='https://en.wikipedia.org/wiki/Land_use'>land use decisions</a>
                </li>
                <li>
                    Approving the <a href='https://en.wikipedia.org/wiki/Budget'>city's budget</a>
                </li>
            </ul>


            <p>Below are the primary types of city council activity.</p>

            <table class="table">
                <thead>
                    <tr>
                        <th>Legislation Type</th>
                        <th>Description</th>
                    </tr>
                </thead>
                <tbody>
                {% for leg_type in legislation_type_descriptions %}
                    <tr>
                        <td>
                            <i class="fa fa-fw fa-{{leg_type.fa_icon}}"></i> 
                            <a href="/search/?q=&selected_facets=bill_type_exact:{{leg_type.search_term}}">
                                {{leg_type.name}}
                            </a>
                        </td>
                        <td>
                            {% if leg_type.html_desc %}
                                <p>{{leg_type.desc|safe}}</p>
                            {% else %}
                                <p>{{leg_type.desc}}</p>
                            {% endif %}
                        </td>
                    </tr>
                {% endfor %}
                </tbody>
            </table>

            <p>
                <strong>Introductions</strong> are the most interesting type of legislation because they are proposals for new laws. Once an introduction is passed, it becomes a Local Law - <a href="http://legistar.council.nyc.gov/LegislationDetail.aspx?ID=2328524&GUID=E0B4EE30-B5F7-4E90-9C97-CF96D5385E01" target="_blank">see all Local Laws for 2015</a>.
            </p>

            <p>
                Most of the Council's legislative action happens in <a href='/committees/'>committees</a>. Each committee meets in public hearings 2-3 times per month where proposed legislation is debated. Members of other government branches, as well as the public, are able to attend and comment at these hearings.
            </p>

            <p>
                Meetings of the entire Council, referred to as Stated Meetings, occur twice a month at City Hall. 
            </p>
        </div>
    </div>
    <div class="row-fluid">
        <div class="col-sm-8 no-pad-mobile" id="open-source">
            <br/></br>

            <h3>We're open source!</h3>

            <p>
                This website is open source and on <a href="https://github.com/datamade/nyc-councilmatic">GitHub</a> - meaning that anyone can re-use or adapt the code.
            </p>
        </div>
    </div>
    <div class="row-fluid">
        <div class="col-sm-8 no-pad-mobile" id="data">
            <br/></br>

            <h3>Data</h3>
            <p>The data from this website comes from <a href='http://legistar.council.nyc.gov/'>New York City Council's Legislative Research Center</a>, a system built by <a href='http://www.granicus.com/'>Granicus</a> using their <a href='http://www.granicus.com/solutions/legislative-management/'>Legistar Legislative Management Suite</a>.</p>

            <p>This data is then collected daily using the <a href="http://opencivicdata.org/about/" target="_blank">Open Civic Data</a> standard and platform. Open Civic Data standardizes information about people, organizations, events and bills at any level of government and was built in collaboration with <a href="http://sunlightfoundation.com/">The Sunlight Foundation</a>, <a href="https://developers.google.com/civic-information/?hl=en">Google</a>, <a href="http://www.granicus.com/">Granicus</a> and <a href="http://www.opennorth.ca/">Open North</a>.
            </p>

            <p><a href='http://opencivicdata.org'><img style='height:100px;' src='/static/images/ocd.jpg' /></a></p>
        </div>
    </div>
    <div class="row-fluid">
        <div class="col-sm-8 no-pad-mobile" id="team">
            <br/></br>


            <h3>Team</h3>

            <p><a href='http://www.participatorypolitics.org/'><img style='height:100px;' src='/static/images/ppf-logo.png' /></a></p>

            <p>NYC Councilmatic is brought to you by the <a href='http://www.participatorypolitics.org/'>Participatory Politics Foundation</a>, a NYC-based 501(c)3 non-profit organisation with a mission to increase civic engagement. David Moore is the program manager, based out of the Civic Hall community space.</p>

            <p><a href='http://datamade.us'><img style='height:50px;' src='/static/images/datamade-logo.png' /></a></p>

            <p>The site was built by <a href='http://datamade.us'>DataMade</a>, a civic technology company. They build open source technology using open data to empower journalists, researchers, governments and advocacy organizations.</p>

            <p><a href='http://www.ritaallen.org'><img style='height:100px;' src='/static/images/rita-allen-logo.png' /></a></p>

            <p>Funding for this project was provied by <a href='http://www.ritaallen.org'>The Rita Allen Foundation</a>, which is actively interested in promoting civic literacy and engagement, investing in young leaders in the sciences and social innovation, and building stronger communities.</p>
        </div>
    </div>

    <div class="row-fluid">
        <div class="col-sm-8 no-pad-mobile" id="contact">
            <br/></br>

            <h3>Contact us</h3>

            <p>Have a question about information you were seeking to find, or explanations of how NYC Council works? Send us an email <a href='mailto:info@councilmatic.org'>info@councilmatic.org</a>.</p>

            <p>You can also follow us <a href='https://twitter.com/councilmatic'><i class='fa fa-fw fa-twitter'></i> Twitter</a> and <a href='https://www.facebook.com/councilmatic?ref=hl'><i class='fa fa-fw fa-facebook'></i> Facebook</a>.</p>

            <p>Developer people: if you notice a bug, file an issue on our <a href='https://github.com/datamade/nyc-councilmatic/'>issue tracker</a>!</p>
            
            
        </div>
    </div>

    <div class="row-fluid">
        <div class="col-sm-8 no-pad-mobile" id="bring-councilmatic">
            <br/></br>

            <h3>Bring Councilmatic to your city!</h3>

            <p>The Participatory Politics Foundation and DataMade are committeed to spreading the Councilmatic platform to every city so everyone can stay informed on the actions of their local city council.</p>

            <p>
                If you're interested in bringing Councilmatic to your city, sent us an email at <a href="mailto:info@councilmatic.org">info@councilmatic.org</a>!
            </p>
            
        </div>
    </div>

    <div class="row-fluid">
        <div class="col-sm-8 no-pad-mobile" id="credits">
            <br/></br>

            <h3>Credits</h3>
            <p><strong>Councilmatic</strong> was originally created by <a href='https://twitter.com/mjumbewu'>Mjumbe Poe</a> for <a href='http://philly.councilmatic.org'>Philidelphia</a>, during his time as a 2011 <a href='http://www.codeforamerica.org/'>Code For America</a> Fellow. It was the first fully-developed open data site for municipal legislation in the United States.</p>

            <h4>Additional credits</h4>
            <ul>
                <li>Logo: <a href="https://thenounproject.com/term/statue-of-liberty/58183/" target="_blank">Statue of Liberty</a> by Tyler Comrie, from the <a href="https://thenounproject.com/" target="_blank">Noun Project</a></li>
                <li>Photo: <a href="https://commons.wikimedia.org/wiki/File:New_York_City_Hall.jpg">New York City Hall</a> by Momos, <a href="http://creativecommons.org/licenses/by-sa/3.0/" target="_blank">CC BY-SA 3.0</a></li>
                <li>Photo: <a href='http://www.nydailynews.com/new-york/city-council-members-put-body-cameras-article-1.2180212'>Police body cameras</a> by AP/Jeff Chiu</li>
            </ul>
            
        </div>
    </div>


{% endblock %}